@@ -4,6 +4,7 @@
 #'
 #' @param data a data frame object.
 #' @param Var a character vector naming the variables you would like to have only non-missing (NA) values.
+#' @param message logical. Whether or not to give you a message about the number of rows that are dropped.
 #'
 #' @examples
 #' # Create data frame
@@ -12,7 +13,7 @@
 #' ABData <- data.frame(a, b)
 #' 
 #' # Remove missing values from column a
-#' ASubData <- DropNA(ABData, Var = "a")
+#' ASubData <- DropNA(ABData, Var = "a", message = FALSE)
 #' 
 #' # Remove missing values in columns a and b
 #' ABSubData <- DropNA(ABData, Var = c("a", "b"))
@@ -21,7 +22,7 @@
 #'
 #' @export
 
-DropNA <- function(data, Var)
+DropNA <- function(data, Var, message = TRUE)
 {
 	# Find term number
 	DataNames <- names(data)
@@ -45,6 +46,8 @@ DropNA <- function(data, Var)
 		TotalDropped <- sum(RowNA)
 	}	
 
-	message(paste(TotalDropped, "rows dropped from the data frame." ))
+  if (isTRUE(message)){
+	  message(paste(TotalDropped, "rows dropped from the data frame." ))
+  }
 	return(DataNoNA)
 }
