@@ -7,6 +7,7 @@
 #' @param GroupVar a character string naming the variable grouping the units within which \code{Var} will be slid. If \code{GroupVar = NULL} then the whole variable is slid up or down. This is similar to \code{\link{shift}}, though \code{shift} returns the slid data to a new vector rather than the original data frame.
 #' @param NewVar a character string specifying the name for the new variable to place the slid data in.
 #' @param slideBy numeric value specifying how many rows (time units) to shift the data by. Negative values slide the data down--lag the data. Positive values shift the data up--lead the data.
+#' @param reminder logical. Whether or not to remind you to order your data by the \code{GroupVar} and time variable before running \code{slide}.
 #'  
 #'  @examples
 #'  # Create dummy data
@@ -34,8 +35,16 @@
 #' @importFrom plyr ddply rename
 #' @export
 
-slide <- function(data, Var, GroupVar = NULL, NewVar = NULL, slideBy = -1)
+slide <- function(data, Var, GroupVar = NULL, NewVar = NULL, slideBy = -1, reminder = TRUE)
 {
+  if (isTRUE(reminder)){
+    if (is.null(GroupVar)){
+      message(paste('Remember to put', deparse(substitute(data)), 'in time order before running slide.'))      
+    } else if (!is.null(GroupVar)){
+      message(paste('Remember to order', deparse(substitute(data)), 'by', GroupVar, 'and the time variable before running slide.'))
+    }
+  }
+  
   # Determine if Var exists in data
   DataNames <- names(data)
   TestExist <- Var %in% DataNames
